NativeToastLength class
Constructors
- NativeToastLength.ms(int durationMs)
-
const
Properties
- durationMs → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- ages → const NativeToastLength
- long → const NativeToastLength
- medium → const NativeToastLength
- never → const NativeToastLength
- short → const NativeToastLength