NativeToastOptions class
Constructors
- NativeToastOptions({ToastPosition position = ToastPosition.top, NativeToastLength length = NativeToastLength.short, Color? bgColor, NativeToastIcon? icon, NativeToastDismissDirection? dismissDirection})
-
const
Properties
- bgColor → Color?
-
final
- dismissDirection → NativeToastDismissDirection?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → NativeToastIcon?
-
final
- length → NativeToastLength
-
final
- position → ToastPosition
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited